@@ -68,6 +68,10 @@ class Geo_common:
                 if_same = FastqToFC.diff_r1_r2(r1,r2)
                 if not if_same:
                     exit("错误: %s 与 %s 不是对应的双端序列!" %(r1,r2))
+        # groups: 每个比对组包含的样本 , dict = {group1 : [sample1 , smaple2] , group2 : [sample3 , sample4]}
+        self.groups = collections.defaultdict(list)
+        for sample in self.samples:
+            self.groups[self.samples[sample]["group"]].append(sample)
         # compare_group: 比对组信息 , list = [treat__control]
         self.compare_group = []
         for line in ParserXLS.fetch_row(excel, main_name, "COMPARE_GROUP")[1:]:
